==> python-pygls-0.10.2-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/pygls/lsp/types/language_features/formatting.py <==
############################################################################
# Original work Copyright 2017 Palantir Technologies, Inc.                 #
# Original work licensed under the MIT License.                            #
# See ThirdPartyNotices.txt in the project root for license information.   #
# All modifications Copyright (c) Open Law Library. All rights reserved.   #
#                                                                          #
# Licensed under the Apache License, Version 2.0 (the "License")           #
# you may not use this file except in compliance with the License.         #
# You may obtain a copy of the License at                                  #
#                                                                          #
#     http: // www.apache.org/licenses/LICENSE-2.0                         #
#                                                                          #
# Unless required by applicable law or agreed to in writing, software      #
# distributed under the License is distributed on an "AS IS" BASIS,        #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
# See the License for the specific language governing permissions and      #
# limitations under the License.                                           #
############################################################################
"""This module contains Language Server Protocol types
https://microsoft.github.io/language-server-protocol/specification

-- Language Features - Formatting --

Class attributes are named with camel-case notation because client is expecting
that.
"""
from typing import Optional

from pygls.lsp.types.basic_structures import (Model, TextDocumentIdentifier,
                                              WorkDoneProgressOptions, WorkDoneProgressParams)


class DocumentFormattingClientCapabilities(Model):
    dynamic_registration: Optional[bool] = False


class DocumentFormattingOptions(WorkDoneProgressOptions):
    pass


class FormattingOptions(Model):
    tab_size: int
    insert_spaces: bool
    trim_trailing_whitespace: Optional[bool] = False
    insert_final_newline: Optional[bool] = False
    trim_final_newlines: Optional[bool] = False


class DocumentFormattingParams(WorkDoneProgressParams):
    text_document: TextDocumentIdentifier
    options: FormattingOptions

==> python-pygls-0.12.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/pygls/lsp/types/language_features/formatting.py <==
############################################################################
# Original work Copyright 2017 Palantir Technologies, Inc.                 #
# Original work licensed under the MIT License.                            #
# See ThirdPartyNotices.txt in the project root for license information.   #
# All modifications Copyright (c) Open Law Library. All rights reserved.   #
#                                                                          #
# Licensed under the Apache License, Version 2.0 (the "License")           #
# you may not use this file except in compliance with the License.         #
# You may obtain a copy of the License at                                  #
#                                                                          #
#     http: // www.apache.org/licenses/LICENSE-2.0                         #
#                                                                          #
# Unless required by applicable law or agreed to in writing, software      #
# distributed under the License is distributed on an "AS IS" BASIS,        #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
# See the License for the specific language governing permissions and      #
# limitations under the License.                                           #
############################################################################
"""This module contains Language Server Protocol types
https://microsoft.github.io/language-server-protocol/specification

-- Language Features - Formatting --

Class attributes are named with camel case notation because client is expecting
that.
"""
from typing import Optional

from pygls.lsp.types.basic_structures import (Model, TextDocumentIdentifier,
                                              WorkDoneProgressOptions, WorkDoneProgressParams)


class DocumentFormattingClientCapabilities(Model):
    dynamic_registration: Optional[bool]


class DocumentFormattingOptions(WorkDoneProgressOptions):
    pass


class FormattingOptions(Model):
    tab_size: int
    insert_spaces: bool
    trim_trailing_whitespace: Optional[bool]
    insert_final_newline: Optional[bool]
    trim_final_newlines: Optional[bool]


class DocumentFormattingParams(WorkDoneProgressParams):
    text_document: TextDocumentIdentifier
    options: FormattingOptions
